
# Prompt used for initial research/plan/tasks

```
 /ralph-loop:ralph-loop "I really need to demo a seamless experience of using paude with an OpenShift cluster. There's a lot to explore here - we'll have to add an abstraction to our backend for openshift and not just podman. We'll have to figure out where we do builds (in-cluster? locally?), how we get built images into the cluster if local builds, how we connect/disconnect from a pod, how we get the right claude code CLI interface (requires tmux?), how we sync files (mutagen?), and so on. We need research and a comprehensive plan and tasks to accomplish this. Refer to our roadmap and help me plan this out. Ask any questions of me you need to clarify assumptions and to get to a great user experience that takes into account using a repo that is cloned locally to someone's laptop that then needs to get the current state of that code in a container inside openshift with all the required dev dependencies installed, separate venv from host (if using venvs, ie not sharing binaries of deps between host and remote paude container), syncing changes back to the host including git commits (either automatically or explicitly), and disconnecting / reconnecting to a running claude code session in the remote container. We can do this iteratively, but the final task is not complete until all this is researched, planned for, and scoped out into tasks that an Opus 4.5 or Sonnet 4.5 model can implement." --max-iterations 15
```

# Promp used for implementation

```
/ralph-loop:ralph-loop "Implement the feature described in docs/features/PENDING-openshift-backend. Review the materials there, and systematically and iteratively implement all of the tasks and other necessary discovered work, including tests, for the new openshift backend. Do not try to implement everything in one big bang, but instead start small and implement it in multiple iterations. Keep track of your work and do not stop until all tasks are complete. Once you think all tasks are complete, double-check the actual implementation against the task list to ensure nothing was missed. All tests should pass when complete. This implementation is being done from within a paude container, so you will be able to actually run paude containers in your testing so be sure to use unit tests or dry-run commands. Once all that is done, ensure the user experience matches the vision of the feature and will work seamlessly without bugs." --max-iterations 15
```
